@@ -28,7 +28,8 @@ class Library:
             return
         # Protect by Cloudflare or Proxy required
         try:
-            response = requests.get(Library.base_url, proxies={"http": self.http_proxy})
+            response = requests.get(Library.base_url, proxies={
+                                    "http": self.http_proxy})
             if response.text.find("Cloudflare") != -1:
                 raise Exception()
         except Exception:
@@ -57,7 +58,8 @@ class Library:
             'Accept': 'text/event-stream',
             'Accept-Encoding': 'gzip'
         }
-        response = requests.get(URL, proxies={"http": self.http_proxy}, headers=headers)
+        response = requests.get(
+            URL, proxies={"http": self.http_proxy}, headers=headers)
 
         # parse html
         soup = bs4.BeautifulSoup(response.content, features="html.parser")
@@ -69,13 +71,14 @@ class Library:
             video = thumblist.select(".video > a")
             if video is None:
                 raise Exception("Not recruited")
-            
+
             # multiple result - choose the last one
             if video[0]['title'].endswith("（BOD）") or video[0]['title'].endswith("（ブルーレイディスク）"):
                 video = video[1:]
 
             URL = Library.base_url + video[0]['href']
-            response = requests.get(URL, proxies={"http": self.http_proxy}, headers=headers)
+            response = requests.get(
+                URL, proxies={"http": self.http_proxy}, headers=headers)
             soup = bs4.BeautifulSoup(response.content, features="html.parser")
 
         # video title
@@ -85,6 +88,17 @@ class Library:
         result["cover_url"] = "http:" + \
             soup.select_one("#video_jacket_img")["src"]
 
+        # outline <Airav>
+        try:
+            airav_URL = encode("gssor9..vvv-`hq`u-vhjh.uhcdn.") + designatio
+            outline_rep = requests.get(
+                airav_URL, proxies={"http": self.http_proxy}, headers=headers)
+            airav_soup = bs4.BeautifulSoup(
+                outline_rep.content, features="html.parser")
+            result["outline"] = airav_soup.select_one(".synopsis > p").string
+        except:
+            pass
+
         # Attributes Extract lambda function
         extract = {
             "designatio": lambda s: s.select_one("#video_id .text").getText(),
